@@ -1,13 +1,17 @@
 use super::{
   lovense_dongle_messages::{
-    LovenseDeviceCommand, LovenseDongleIncomingMessage, OutgoingLovenseData,
+    LovenseDeviceCommand,
+    LovenseDongleIncomingMessage,
+    OutgoingLovenseData,
   },
   lovense_dongle_state_machine::create_lovense_dongle_machine,
 };
 use crate::{
   core::ButtplugResultFuture,
   server::comm_managers::{
-    DeviceCommunicationEvent, DeviceCommunicationManager, DeviceCommunicationManagerBuilder,
+    DeviceCommunicationEvent,
+    DeviceCommunicationManager,
+    DeviceCommunicationManagerBuilder,
   },
   util::async_manager,
 };
@@ -34,13 +38,15 @@ fn serial_write_thread(
 ) {
   let mut port_write = |mut data: String| {
     data += "\r\n";
-    info!("Writing message: {}", data);
+    debug!("Writing message: {}", data);
 
     // TODO WRITE SHOULD ALWAYS BE FOLLOWED BY A READ UNLESS "EAGER" IS USED
     //
     // We should check this on the outgoing message. Otherwise we will run into
     // all sorts of trouble.
-    port.write_all(&data.into_bytes()).unwrap();
+    if let Err(e) = port.write_all(&data.into_bytes()) {
+      error!("Cannot write to port: {}", e);
+    }
   };
   while let Some(data) = async_manager::block_on(async {
     select! {
@@ -53,7 +59,9 @@ fn serial_write_thread(
         port_write(s);
       }
       OutgoingLovenseData::Message(m) => {
-        port_write(serde_json::to_string(&m).unwrap());
+        port_write(
+          serde_json::to_string(&m).expect("We create these packets so they'll always serialize."),
+        );
       }
     }
   }
@@ -71,7 +79,8 @@ fn serial_read_thread(
     match port.read(&mut buf) {
       Ok(len) => {
         debug!("Got {} serial bytes", len);
-        data += std::str::from_utf8(&buf[0..len]).unwrap();
+        data += std::str::from_utf8(&buf[0..len])
+          .expect("We should always get valid data from the port.");
         if data.contains('\n') {
           debug!("Serial Buffer: {}", data);
 
@@ -81,7 +90,12 @@ fn serial_read_thread(
             match msg {
               Ok(m) => {
                 debug!("Read message: {:?}", m);
-                async_manager::block_on(async { sender_clone.send(m).await.unwrap() });
+                async_manager::block_on(async {
+                  sender_clone
+                    .send(m)
+                    .await
+                    .expect("Thread shouldn't be running if we don't have a listener.")
+                });
               }
               Err(e) => {
                 error!("Error reading: {:?}", e);
@@ -124,7 +138,10 @@ impl DeviceCommunicationManagerBuilder for LovenseSerialDongleCommunicationManag
 
   fn finish(mut self) -> Box<dyn DeviceCommunicationManager> {
     Box::new(LovenseSerialDongleCommunicationManager::new(
-      self.sender.take().unwrap(),
+      self
+        .sender
+        .take()
+        .expect("We own this so take will always work."),
     ))
   }
 }
@@ -155,8 +172,7 @@ impl LovenseSerialDongleCommunicationManager {
       if let Err(err) = dongle_fut.await {
         error!("Error finding serial dongle: {:?}", err);
       }
-    })
-    .unwrap();
+    });
     let mut machine =
       create_lovense_dongle_machine(event_sender, machine_receiver, mgr.is_scanning.clone());
     async_manager::spawn(
@@ -169,8 +185,7 @@ impl LovenseSerialDongleCommunicationManager {
         parent: tracing::Span::current(),
         "Lovense Serial Dongle State Machine"
       )),
-    )
-    .unwrap();
+    );
     mgr
   }
 
@@ -206,21 +221,25 @@ impl LovenseSerialDongleCommunicationManager {
                       let (writer_sender, writer_receiver) = channel(256);
                       let (reader_sender, reader_receiver) = channel(256);
 
-                      let read_port = (*dongle_port).try_clone().unwrap();
+                      let read_port = (*dongle_port)
+                        .try_clone()
+                        .expect("USB port should always clone.");
                       let read_thread = thread::Builder::new()
                         .name("Serial Reader Thread".to_string())
                         .spawn(move || {
                           serial_read_thread(read_port, reader_sender, read_token);
                         })
-                        .unwrap();
+                        .expect("Thread should always create");
 
-                      let write_port = (*dongle_port).try_clone().unwrap();
+                      let write_port = (*dongle_port)
+                        .try_clone()
+                        .expect("USB port should always clone.");
                       let write_thread = thread::Builder::new()
                         .name("Serial Writer Thread".to_string())
                         .spawn(move || {
                           serial_write_thread(write_port, writer_receiver, write_token);
                         })
-                        .unwrap();
+                        .expect("Thread should always create");
 
                       *(held_read_thread.lock().await) = Some(read_thread);
                       *(held_write_thread.lock().await) = Some(write_thread);
@@ -230,7 +249,7 @@ impl LovenseSerialDongleCommunicationManager {
                           reader_receiver,
                         ))
                         .await
-                        .unwrap();
+                        .expect("Machine exists if we got here.");
                     }
                     Err(e) => error!("{:?}", e),
                   };
@@ -264,7 +283,7 @@ impl DeviceCommunicationManager for LovenseSerialDongleCommunicationManager {
       sender
         .send(LovenseDeviceCommand::StartScanning)
         .await
-        .unwrap();
+        .expect("If we're getting scan requests, we should a task to throw it at.");
       Ok(())
     })
   }
@@ -275,7 +294,7 @@ impl DeviceCommunicationManager for LovenseSerialDongleCommunicationManager {
       sender
         .send(LovenseDeviceCommand::StopScanning)
         .await
-        .unwrap();
+        .expect("If we're getting scan requests, we should a task to throw it at.");
       Ok(())
     })
   }
