@@ -1,12 +1,14 @@
 // The tests in this file can fail on CI if there isn't a timed retry.
 
-#[cfg(feature = "websockets")]
+#[cfg(all(feature = "websockets", target = "windows"))]
 mod websocket_connector_tests {
   use buttplug::{
     client::ButtplugClient,
     connector::{
-      ButtplugRemoteClientConnector, ButtplugRemoteServerConnector,
-      ButtplugWebsocketClientTransport, ButtplugWebsocketServerTransport,
+      ButtplugRemoteClientConnector,
+      ButtplugRemoteServerConnector,
+      ButtplugWebsocketClientTransport,
+      ButtplugWebsocketServerTransport,
       ButtplugWebsocketServerTransportBuilder,
     },
     core::messages::serializer::{ButtplugClientJSONSerializer, ButtplugServerJSONSerializer},
@@ -27,10 +29,16 @@ mod websocket_connector_tests {
         let connector = ButtplugRemoteServerConnector::<
           ButtplugWebsocketServerTransport,
           ButtplugServerJSONSerializer,
-        >::new(ButtplugWebsocketServerTransportBuilder::default().port(12349).finish());
-        server_clone.start(connector).await.unwrap();
-      })
-      .unwrap();
+        >::new(
+          ButtplugWebsocketServerTransportBuilder::default()
+            .port(12349)
+            .finish(),
+        );
+        server_clone
+          .start(connector)
+          .await
+          .expect("Test, assuming infallible.");
+      });
       let mut connected = false;
       for _ in 0..10u8 {
         let connector = ButtplugRemoteClientConnector::<
@@ -48,7 +56,10 @@ mod websocket_connector_tests {
         Delay::new(Duration::from_secs(1)).await;
       }
       assert!(connected);
-      server.disconnect().await.unwrap();
+      server
+        .disconnect()
+        .await
+        .expect("Test, assuming infallible.");
     });
   }
 
@@ -65,16 +76,22 @@ mod websocket_connector_tests {
         >::new(ButtplugWebsocketClientTransport::new_insecure_connector(
           "ws://127.0.0.1:12347",
         ));
-        server_clone.start(connector).await.unwrap();
-      })
-      .unwrap();
+        server_clone
+          .start(connector)
+          .await
+          .expect("Test, assuming infallible.");
+      });
 
       let mut connected = false;
       for _ in 0..10u8 {
         let connector = ButtplugRemoteClientConnector::<
           ButtplugWebsocketServerTransport,
           ButtplugClientJSONSerializer,
-        >::new(ButtplugWebsocketServerTransportBuilder::default().port(12347).finish());
+        >::new(
+          ButtplugWebsocketServerTransportBuilder::default()
+            .port(12347)
+            .finish(),
+        );
 
         let client = ButtplugClient::new("Test Client");
         if client.connect(connector).await.is_ok() {
@@ -84,7 +101,10 @@ mod websocket_connector_tests {
         Delay::new(Duration::from_secs(1)).await;
       }
       assert!(connected);
-      server.disconnect().await.unwrap();
+      server
+        .disconnect()
+        .await
+        .expect("Test, assuming infallible.");
     });
   }
 }
